
<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://img.riminder.net/logo-hrflow.svg" width="120" />
  </a>
</p>
<h1 align="center">
  Talentsoft connectors
</h1>


<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://gblobscdn.gitbook.com/assets%2F-M1L6Hspq8r9LXd5_gIC%2F-MDFJEJiBWX89GZj9HG5%2F-MDFs1URFZR6KkAzvr3h%2Fimage.png?alt=media&token=6084e888-b39c-4bfb-abb1-4f9c59b7d2e6"/>
  </a>
</p>

<br/>

Fo


